@@ -1,5 +1,4 @@
 package Module::Starter;
-# vi:et:sw=4 ts=4
 
 use warnings;
 use strict;
@@ -11,11 +10,11 @@ Module::Starter - a simple starter kit for any module
 
 =head1 VERSION
 
-version 1.52
+version 1.55
 
 =cut
 
-our $VERSION = '1.52';
+our $VERSION = '1.55';
 
 =head1 SYNOPSIS
 
@@ -47,19 +46,32 @@ populates it with the all the requires files.
 
 It takes a hash of params, as follows:
 
-    distro  => $distroname,      # distribution name (defaults to first module)
-    modules => [ module names ], # modules to create in distro
-    dir     => $dirname,         # directory in which to build distro
-    builder => 'Module::Build',  # defaults to ExtUtils::MakeMaker
-                                 # or specify more than one builder in an
-                                 # arrayref
+    distro       => $distroname,      # distribution name (defaults to first module)
+    modules      => [ module names ], # modules to create in distro
+    dir          => $dirname,         # directory in which to build distro
+    builder      => 'Module::Build',  # defaults to ExtUtils::MakeMaker
+                                      # or specify more than one builder in an
+                                      # arrayref
 
-    license => $license,  # type of license; defaults to 'perl'
-    author  => $author,   # author's full name (required)
-    email   => $email,    # author's email address (required)
+    license      => $license,  # type of license; defaults to 'perl'
+    author       => $author,   # author's full name (required)
+    email        => $email,    # author's email address (required)
+    ignores_type => $type,     # ignores file type ('generic', 'cvs', 'git', 'manifest' )
 
-    verbose => $verbose,  # bool: print progress messages; defaults to 0
-    force   => $force     # bool: overwrite existing files; defaults to 0
+    verbose      => $verbose,  # bool: print progress messages; defaults to 0
+    force        => $force     # bool: overwrite existing files; defaults to 0
+
+The ignores_type is a new feature that allows to create SCM-specific ignore files.
+These are the mappings:
+
+    ignores_type => 'generic'  # default, creates 'ignore.txt'
+    ignores_type => 'cvs'      # creates .cvsignore
+    ignores_type => 'git'      # creates .gitignore
+    ignores_type => 'manifest' # creates MANIFEST.SKIP
+
+It is also possible to provide an array ref with multiple types wanted:
+
+    ignores_type => [ 'git', 'manifest' ]
 
 =head1 PLUGINS
 
@@ -99,6 +111,8 @@ sub import {
 
 =head1 AUTHORS
 
+Sawyer X, C<< <xsawyerx at cpan.org> >>
+
 Andy Lester, C<< <petdance at cpan.org> >>
 
 Ricardo Signes, C<< <rjbs at cpan.org> >>
@@ -111,7 +125,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Module::Starter
 
-    You can also look for information at:
+You can also look for information at:
 
 =over 4
 
@@ -146,12 +160,16 @@ notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT
 
-Copyright 2005-7 Andy Lester, Ricardo Signes and C.J. Adams-Collier,
+Copyright 2005-2009 Andy Lester, Ricardo Signes and C.J. Adams-Collier,
 All Rights Reserved.
 
+Copyright 2010 Sawyer X, All Rights Reserved.
+
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
 1;
+
+# vi:et:sw=4 ts=4
