@@ -1,5 +1,4 @@
 package Module::Starter::BuilderSet;
-# vi:et:sw=4 ts=4
 
 use strict;
 use warnings;
@@ -12,11 +11,11 @@ Module::Starter::BuilderSet - determine builder metadata
 
 =head1 VERSION
 
-Version 1.52
+Version 1.55
 
 =cut
 
-our $VERSION = '1.52';
+our $VERSION = '1.55';
 
 =head1 SYNOPSIS
 
@@ -34,6 +33,10 @@ our $VERSION = '1.52';
     my @builder_dependencies = $builder_set->deps_for_builder($default_builder);
     my @compatible_builders = $builder_set->check_compatibility(@builder_list);
 
+    my $ms_simple    = Module::Starter::Simple->new();
+    my $build_method = $builder_set->manifest_method($builder);
+    $ms_simple->$build_method();
+
 =head1 DESCRIPTION
 
 Module::Starter::BuilderSet is a collection of utility methods used to
@@ -55,42 +58,45 @@ sub new {
       {
        'Module::Build' =>
        {
-        file         => "Build.PL",
-        build_method => "create_Build_PL",
-        build_deps   => [],
-        instructions => [ 'perl Build.PL',
-                          './Build',
-                          './Build test',
-                          './Build install',
-                        ],
+        file           => "Build.PL",
+        build_method   => "create_Build_PL",
+        build_deps     => [],
+        build_manifest => 'create_MB_MANIFEST',
+        instructions   => [ 'perl Build.PL',
+                            './Build',
+                            './Build test',
+                            './Build install',
+                          ],
        },
        'Module::Install' =>
        {
-        file         => "Makefile.PL",
-        build_method => "create_MI_Makefile_PL",
-        build_deps   => [],
-        instructions => [ 'perl Makefile.PL',
-                          'make',
-                          'make test',
-                          'make install',
-                        ],
+        file           => "Makefile.PL",
+        build_method   => "create_MI_Makefile_PL",
+        build_deps     => [],
+        build_manifest => 'create_MI_MANIFEST',
+        instructions   => [ 'perl Makefile.PL',
+                            'make',
+                            'make test',
+                            'make install',
+                          ],
        },
        'ExtUtils::MakeMaker' =>
        {
-        file         => "Makefile.PL",
-        build_method => "create_Makefile_PL",
-        build_deps   => [ { command => 'make',
-                            aliases => [ 'make', 'gmake' ],
-                          },
-                          { command => 'chmod',
-                            aliases => [ 'chmod' ],
-                          },
-                        ],
-        instructions => [ 'perl Makefile.PL',
-                          'make',
-                          'make test',
-                          'make install',
-                        ],
+        file           => "Makefile.PL",
+        build_method   => "create_Makefile_PL",
+        build_manifest => 'create_EUMM_MANIFEST',
+        build_deps     => [ { command => 'make',
+                              aliases => [ 'make', 'gmake' ],
+                            },
+                            { command => 'chmod',
+                              aliases => [ 'chmod' ],
+                            },
+                          ],
+        instructions   => [ 'perl Makefile.PL',
+                            'make',
+                            'make test',
+                            'make install',
+                          ],
        }
       };
 
@@ -189,6 +195,19 @@ sub deps_for_builder {
     return @{ $self->_builder($builder)->{build_deps} };
 }
 
+=head2 C<< manifest_method($builder) >>
+
+This method returns the command to run to create the manifest according to the
+builder asked.
+
+=cut
+
+sub manifest_method {
+    my ( $self, $builder ) = @_;
+
+    return $self->_builder($builder)->{'build_manifest'};
+}
+
 =head2 C<< check_compatibility(@builders) >>
 
 This method accepts a list of builders and filters out the ones that
@@ -274,5 +293,6 @@ employers of the various contributors to the code.
 
 =cut
 
-
 1;
+
+# vi:et:sw=4 ts=4
