@@ -1,9 +1,10 @@
 package Module::Starter::Simple;
-# vi:et:sw=4 ts=4
 
+use 5.006;
 use strict;
 use warnings;
 
+use Cwd 'cwd';
 use ExtUtils::Command qw( rm_rf mkpath touch );
 use File::Spec ();
 use Carp qw( carp confess croak );
@@ -16,11 +17,11 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.52
+Version 1.55
 
 =cut
 
-our $VERSION = '1.52';
+our $VERSION = '1.55';
 
 =head1 SYNOPSIS
 
@@ -37,55 +38,6 @@ the directories with the required files.
 
 =head1 CLASS METHODS
 
-=head2 C<< create_distro(%args) >>
-
-This method works as advertised in L<Module::Starter>.
-
-=cut
-
-sub create_distro {
-    my $class = shift;
-
-    my $self = $class->new( @_ );
-
-    my $modules = $self->{modules} || [];
-    my @modules = map { split /,/ } @{$modules};
-    croak "No modules specified.\n" unless @modules;
-    for (@modules) {
-        croak "Invalid module name: $_" unless /\A[a-z_]\w*(?:::[\w]+)*\Z/i;
-    }
-
-    croak "Must specify an author\n" unless $self->{author};
-    croak "Must specify an email address\n" unless $self->{email};
-    ($self->{email_obfuscated} = $self->{email}) =~ s/@/ at /;
-
-    $self->{license} ||= 'perl';
-
-    $self->{main_module} = $modules[0];
-    if ( not $self->{distro} ) {
-        $self->{distro} = $self->{main_module};
-        $self->{distro} =~ s/::/-/g;
-    }
-
-    $self->{basedir} = $self->{dir} || $self->{distro};
-    $self->create_basedir;
-
-    my @files;
-    push @files, $self->create_modules( @modules );
-
-    push @files, $self->create_t( @modules );
-    push @files, $self->create_ignores;
-    my %build_results = $self->create_build();
-    push(@files, @{ $build_results{files} } );
-
-    push @files, $self->create_Changes;
-    push @files, $self->create_README( $build_results{instructions} );
-    push @files, 'MANIFEST';
-    $self->create_MANIFEST( grep { $_ ne 't/boilerplate.t' } @files );
-
-    return;
-}
-
 =head2 C<< new(%args) >>
 
 This method is called to construct and initialize a new Module::Starter object.
@@ -106,6 +58,93 @@ All the methods documented below are object methods, meant to be called
 internally by the ephemperal objects created during the execution of the class
 method C<create_distro> above.
 
+=head2 postprocess_config
+
+A hook to do any work after the configuration is initially processed.
+
+=cut
+
+sub postprocess_config { 1 };
+
+=head2 pre_create_distro
+
+A hook to do any work right before the distro is created.
+
+=cut
+
+sub pre_create_distro { 1 };
+
+=head2 C<< create_distro(%args) >>
+
+This method works as advertised in L<Module::Starter>.
+
+=cut
+
+sub create_distro {
+    my $either = shift;
+
+    ( ref $either ) or $either = $either->new( @_ );
+
+    my $self    = $either;
+    my $modules = $self->{modules} || [];
+    my @modules = map { split /,/ } @{$modules};
+    croak "No modules specified.\n" unless @modules;
+    for (@modules) {
+        croak "Invalid module name: $_" unless /\A[a-z_]\w*(?:::[\w]+)*\Z/i;
+    }
+
+    croak "Must specify an author\n" unless $self->{author};
+    croak "Must specify an email address\n" unless $self->{email};
+    ($self->{email_obfuscated} = $self->{email}) =~ s/@/ at /;
+
+    $self->{license}      ||= 'perl';
+    $self->{ignores_type} ||= 'generic';
+
+    $self->{main_module} = $modules[0];
+    if ( not $self->{distro} ) {
+        $self->{distro} = $self->{main_module};
+        $self->{distro} =~ s/::/-/g;
+    }
+
+    $self->{basedir} = $self->{dir} || $self->{distro};
+    $self->create_basedir;
+
+    my @files;
+    push @files, $self->create_modules( @modules );
+
+    push @files, $self->create_t( @modules );
+    push @files, $self->create_ignores;
+    my %build_results = $self->create_build();
+    push(@files, @{ $build_results{files} } );
+
+    push @files, $self->create_Changes;
+    push @files, $self->create_README( $build_results{instructions} );
+
+    $self->create_MANIFEST( $build_results{'manifest_method'} );
+    # TODO: put files to ignore in a more standard form?
+    # XXX: no need to return the files created
+
+    return;
+}
+
+=head2 post_create_distro
+
+A hook to do any work after creating the distribution.
+
+=cut
+
+sub post_create_distro { 1 };
+
+=head2 pre_exit
+
+A hook to do any work right before exit time.
+
+=cut
+
+sub pre_exit {
+     print "Created starter directories and files\n";
+}
+
 =head2 create_basedir
 
 Creates the base directory for the distribution.  If the directory already
@@ -371,7 +410,7 @@ sub _module_to_pm_file {
 sub _reference_links {
   return (
       { nickname => 'RT',
-        title    => 'CPAN\'s request tracker',
+        title    => 'CPAN\'s request tracker (report bugs here)',
         link     => 'http://rt.cpan.org/NoAuth/Bugs.html?Dist=%s',
       },
       { nickname => 'AnnoCPAN',
@@ -459,6 +498,7 @@ sub Makefile_PL_guts {
     (my $author = "$self->{author} <$self->{email}>") =~ s/'/\'/g;
 
     return <<"HERE";
+use 5.006;
 use strict;
 use warnings;
 use ExtUtils::MakeMaker;
@@ -560,6 +600,7 @@ sub Build_PL_guts {
     (my $author = "$self->{author} <$self->{email}>") =~ s/'/\'/g;
 
     return <<"HERE";
+use 5.006;
 use strict;
 use warnings;
 use Module::Build;
@@ -572,6 +613,9 @@ my \$builder = Module::Build->new(
     build_requires => {
         'Test::More' => 0,
     },
+    requires => {
+        'perl' => 5.006,
+    },
     add_to_cleanup      => [ '$self->{distro}-*' ],
     create_makefile_pl => 'traditional',
 );
@@ -684,7 +728,7 @@ sub _README_license {
     my $license_blurb = $self->_license_blurb();
 
 return <<"HERE";
-COPYRIGHT AND LICENCE
+LICENSE AND COPYRIGHT
 
 Copyright (C) $year $self->{author}
 
@@ -769,6 +813,22 @@ eval "use Test::Pod $min_tp";
 plan skip_all => "Test::Pod $min_tp required for testing POD" if $@;
 
 all_pod_files_ok();
+HERE
+
+    $t_files{'manifest.t'} = <<'HERE';
+#!perl -T
+
+use strict;
+use warnings;
+use Test::More;
+
+unless ( $ENV{RELEASE_TESTING} ) {
+    plan( skip_all => "Author tests not required for installation" );
+}
+
+eval "use Test::CheckManifest 0.9";
+plan skip_all => "Test::CheckManifest 0.9 required" if $@;
+ok_manifest();
 HERE
 
     $t_files{'pod-coverage.t'} = <<'HERE';
@@ -794,7 +854,9 @@ HERE
 
     my $nmodules = @modules;
     my $main_module = $modules[0];
-    my $use_lines = join( "\n", map { "    use_ok( '$_' );" } @modules );
+    my $use_lines = join(
+        "\n", map { qq{    use_ok( '$_' ) || print "Bail out!\\n";} } @modules
+    );
 
     $t_files{'00-load.t'} = <<"HERE";
 #!perl -T
@@ -816,6 +878,7 @@ HERE
     $t_files{'boilerplate.t'} = <<"HERE";
 #!perl -T
 
+use 5.006;
 use strict;
 use warnings;
 use Test::More tests => $boilerplate_tests;
@@ -893,37 +956,117 @@ sub _create_t {
     return "t/$filename";
 }
 
-=head2 create_MANIFEST( @files )
+=head2 create_MB_MANIFEST
+
+This methods creates a MANIFEST file using Module::Build's methods.
+
+=cut
+
+sub create_MB_MANIFEST {
+    my $self     = shift;
+    my $orig_dir = cwd();
+
+    # create the MANIFEST in the correct path
+    chdir $self->{'basedir'} || die "Can't reach basedir: $!\n";
+
+    my $name = $self->{'main_module'};
+    $name || die q{Couldn't find valid name for distribution};
+
+    require Module::Build;
+    my $mb = Module::Build->new( module_name => $name, verbose => 0 )
+                          ->dispatch('manifest');
+
+    # return to our original path, wherever it was
+    chdir $orig_dir || die "Can't return to original dir: $!\n";
+}
+
+=head2 create_MI_MANIFEST
+
+This method creates a MANIFEST file using Module::Install's methods.
+
+Currently runs ExtUtils::MakeMaker's methods.
+
+=cut
+
+sub create_MI_MANIFEST {
+    my $self = shift;
+    $self->create_EUMM_MANIFEST;
+}
+
+=head2 create_EUMM_MANIFEST
+
+This method creates a MANIFEST file using ExtUtils::MakeMaker's methods.
+
+=cut
+
+sub create_EUMM_MANIFEST {
+    my $self     = shift;
+    my $orig_dir = cwd();
+
+    # create the MANIFEST in the correct path
+    chdir $self->{'basedir'} || die "Can't reach basedir: $!\n";
+
+    require ExtUtils::Manifest;
+    ExtUtils::Manifest->import('mkmanifest');
+    $ExtUtils::Manifest::Quiet = 0;
+
+    mkmanifest();
+
+    # return to our original path, wherever it was
+    chdir $orig_dir || die "Can't return to original dir: $!\n";
+}
+
+=head2 create_MANIFEST( $method )
 
 This method creates the distribution's MANIFEST file.  It must be run last,
 because all the other create_* functions have been returning the functions they
 create.
 
+It receives a method to run in order to create the MANIFEST file. That way it
+can create a MANIFEST file according to the builder used.
+
 =cut
 
 sub create_MANIFEST {
-    my $self = shift;
-    my @files = @_;
-
+    my ( $self, $manifest_method ) = @_;
     my $fname = File::Spec->catfile( $self->{basedir}, 'MANIFEST' );
-    $self->create_file( $fname, $self->MANIFEST_guts(@files) );
+
+    $self->$manifest_method();
+    $self->filter_lines_in_file(
+        $fname,
+        qr/^t\/boilerplate\.t$/,
+        qr/^ignore\.txt$/,
+    );
+
     $self->progress( "Created $fname" );
 
     return 'MANIFEST';
 }
 
-=head2 MANIFEST_guts( @files )
+=head2 get_builders( )
 
-This method is called by C<create_MANIFEST>, and returns content for the
-MANIFEST file.
+This methods gets the correct builder(s).
+
+It is called by C<create_build>, and returns an arrayref with the builders.
 
 =cut
 
-sub MANIFEST_guts {
+sub get_builders {
     my $self = shift;
-    my @files = sort @_;
 
-    return join( "\n", @files, '' );
+    # pass one: pull the builders out of $self->{builder}
+    my @tmp =
+        ref $self->{'builder'} eq 'ARRAY' ? @{ $self->{'builder'} }
+                                          : $self->{'builder'};
+
+    my @builders;
+    my $COMMA = q{,};
+    # pass two: expand comma-delimited builder lists
+    foreach my $builder (@tmp) {
+        push( @builders, split( $COMMA, $builder ) );
+    }
+
+    return \@builders;
 }
 
 =head2 create_build( )
@@ -940,17 +1083,8 @@ Module::Install
 sub create_build {
     my $self = shift;
 
-    # pass one: pull the builders out of $self->{builder}
-    my @tmp =
-    ref $self->{builder} eq 'ARRAY' ? @{$self->{builder}} : $self->{builder};
-
-    my @builders;
-    my $COMMA = q{,};
-    # pass two: expand comma-delimited builder lists
-    foreach my $builder (@tmp) {
-        push( @builders, split($COMMA, $builder) );
-    }
-
+    # get the builders
+    my @builders    = @{ $self->get_builders };
     my $builder_set = Module::Starter::BuilderSet->new();
 
     # Remove mutually exclusive and unsupported builders
@@ -961,6 +1095,7 @@ sub create_build {
 
     my @build_instructions;
     my @files;
+    my $manifest_method;
 
     foreach my $builder ( @builders ) {
         if ( !@build_instructions ) {
@@ -979,12 +1114,15 @@ sub create_build {
         push( @build_instructions, join("\n", map { "\t$_" } @commands) );
 
         my $build_method = $builder_set->method_for_builder($builder);
-        $self->$build_method($self->{main_module})
+        $self->$build_method($self->{main_module});
+
+        $manifest_method = $builder_set->manifest_method($builder);
     }
 
     return(
-        files        => [ @files ],
-        instructions => join( "\n\n", @build_instructions ),
+        files           => [ @files ],
+        instructions    => join( "\n\n", @build_instructions ),
+        manifest_method => $manifest_method,
     );
 }
 
@@ -997,11 +1135,30 @@ This creates an ignore.txt file for use as MANIFEST.SKIP, .cvsignore,
 =cut
 
 sub create_ignores {
-    my $self = shift;
+    my $self  = shift;
+    my $type  = $self->{ignores_type};
+    my %names = (
+        cvs      => '.cvsignore',
+        git      => '.gitignore',
+        generic  => 'ignore.txt',
+        manifest => 'MANIFEST.SKIP',
+    );
 
-    my $fname = File::Spec->catfile( $self->{basedir}, 'ignore.txt' );
-    $self->create_file( $fname, $self->ignores_guts() );
-    $self->progress( "Created $fname" );
+    my $create_file = sub {
+        my $type  = shift;
+        my $name  = $names{$type};
+        my $fname = File::Spec->catfile( $self->{basedir}, $names{$type} );
+        $self->create_file( $fname, $self->ignores_guts() );
+        $self->progress( "Created $fname" );
+    };
+
+    if ( ref $type eq 'ARRAY' ) {
+        foreach my $single_type ( @{$type} ) {
+            $create_file->($single_type);
+        }
+    } elsif ( ! ref $type ) {
+        $create_file->($type);
+    }
 
     return; # Not a file that goes in the MANIFEST
 }
@@ -1021,12 +1178,14 @@ blib*
 Makefile
 Makefile.old
 Build
+Build.bat
 _build*
 pm_to_blib*
 *.tar.gz
 .lwpcookies
-$self->{distro}-*
 cover_db
+pod2htm*.tmp
+$self->{distro}-*
 HERE
 }
 
@@ -1072,6 +1231,39 @@ sub progress {
     return;
 }
 
+=head2 filter_lines_in_file( $filename, @compiled_regexes )
+
+C<filter_lines_in_file> goes over a file and removes lines with the received
+regexes.
+
+For example, removing t/boilerplate.t in the MANIFEST.
+
+=cut
+
+sub filter_lines_in_file {
+    my ( $self, $file, @regexes ) = @_;
+    my @read_lines;
+    open my $fh, '<', $file or die "Can't open file $file: $!\n";
+    @read_lines = <$fh>;
+    close $fh or die "Can't close file $file: $!\n";
+
+    chomp @read_lines;
+
+    open $fh, '>', $file or die "Can't open file $file: $!\n";
+    foreach my $line (@read_lines) {
+        my $found;
+
+        foreach my $regex (@regexes) {
+            if ( $line =~ $regex ) {
+                $found++;
+            }
+        }
+
+        $found or print {$fh} "$line\n";
+    }
+    close $fh or die "Can't close file $file: $!\n";
+}
+
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -1081,13 +1273,17 @@ be notified of progress on your bug as I make changes.
 
 =head1 AUTHOR
 
+Sawyer X, C<< <xsawyerx@cpan.org> >>
+
 Andy Lester, C<< <andy@petdance.com> >>
 
 C.J. Adams-Collier, C<< <cjac@colliertech.org> >>
 
 =head1 Copyright & License
 
-Copyright 2005-2007 Andy Lester and C.J. Adams-Collier, All Rights Reserved.
+Copyright 2005-2009 Andy Lester and C.J. Adams-Collier, All Rights Reserved.
+
+Copyright 2010 Sawyer X, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -1104,8 +1300,9 @@ sub _module_header {
     my $content = <<"HERE";
 package $module;
 
-use warnings;
+use 5.006;
 use strict;
+use warnings;
 
 \=head1 NAME
 
@@ -1193,7 +1390,7 @@ sub _module_license {
     my $year          = $self->_thisyear();
 
     my $content = qq[
-\=head1 COPYRIGHT & LICENSE
+\=head1 LICENSE AND COPYRIGHT
 
 Copyright $year $self->{author}.
 
@@ -1233,7 +1430,7 @@ Perhaps a little code snippet.
 A list of functions that can be exported.  You can delete this section
 if you don't export anything, such as for a purely object-oriented module.
 
-\=head1 FUNCTIONS
+\=head1 SUBROUTINES/METHODS
 
 \=head2 function1
 
@@ -1267,4 +1464,7 @@ $license
 HERE
     return $content;
 }
+
 1;
+
+# vi:et:sw=4 ts=4
